@@ -1,9 +1,9 @@
 
 __author__ = """N. Cullen <ncullen.th@dartmouth.edu>"""
 
-from external.pyBN.classes.factor import Factor
-from external.pyBN.classes.factorization import Factorization
-from external.pyBN.utils.graph import *
+from bamt.external.pyBN.classes.factor import Factor
+from bamt.external.pyBN.classes.factorization import Factorization
+from bamt.external.pyBN.utils.graph import *
 
 from copy import deepcopy, copy
 import numpy as np
