@@ -8,7 +8,7 @@ Reading
 __author__ = """Nicholas Cullen <ncullen.th@dartmouth.edu>"""
 
 import unittest
-from external.pyBN.readwrite.read import read_bn
+from bamt.external.pyBN.io.read import read_bn
 import os
 from os.path import dirname
 
